@@ -88,7 +88,7 @@ gen <- function(t) {
 #'   generators. This function is syntactic sugar over
 #'   `gen.and_then` to make it palatable for R users.
 #'
-#' @importFrom rlang is_lang
+#' @importFrom rlang is_call
 #' @importFrom rlang caller_env
 #' @importFrom rlang node_cdr
 #' @importFrom rlang node_car
@@ -102,7 +102,7 @@ gen <- function(t) {
 #' })
 generate <- function(loop) {
   loop <- substitute(loop)
-  if (!is_lang(loop, quote(`for`))) {
+  if (!is_call(loop, quote(`for`))) {
     stop("`loop` must be a `for` loop")
   }
 
@@ -562,7 +562,7 @@ gen.list <- function(generator, from = 1, to = NULL, of = NULL) {
     stop("Specify `to` and `from`, or `of`")
 
   if (!missing(of)) {
-    gen(function(size) tree.replicate(of, function() {
+    gen(function(size) tree.replicate(of, function(...) {
         gen.run(generator, size)
     }))
   } else {
